
import { Component, OnInit, OnDestroy, ViewChild, ElementRef, ChangeDetectorRef, HostListener } from '@angular/core';

import { Subject, Subscription, of, Observable } from 'rxjs';
import { map, catchError, take, tap } from 'rxjs/operators';

import { Store, select } from '@ngrx/store';

import { ConfirmationService } from 'primeng/primeng';

import { ProbeService } from '../../service/probe.service';

import * as AppStore from '../../store';
import { DiscoverySession } from '../../core/discovery/discovery-session';


@Component({
  selector: 'app-pages-home',
  templateUrl: './home-page.component.html',
  styleUrls: ['./home-page.component.scss'],
  providers: [
    ConfirmationService,
  ],
})
export class HomePageComponent implements OnInit, OnDestroy {

  blockedDocument = false;

  private preventBrowserCloseSubject: Subject<void>;
  private preventBrowserCloseSubscription: Subscription;

  showWelcomPage$: Observable<boolean>;

  @HostListener('window:beforeunload', ['$event'])
  onBeforeUnload($event: Event) {
    // if (null !== this.discoveryRequestID) {
    //   this.preventBrowserCloseSubject.next();
    //   $event.returnValue = true;
    // }
  }

  constructor(
    private confirmationService: ConfirmationService,
    private probeService: ProbeService,
    private store: Store<any>,
  ) {
    this.preventBrowserCloseSubject = new Subject<void>();
  }

  ngOnInit() {
    this.showWelcomPage$ = this.store.pipe(select(AppStore.EnvironmentSelector.UserSelector.selectShowWelcomPage));

    this.preventBrowserCloseSubscription = this.preventBrowserCloseSubject
      .pipe(
        map(() => {
          this.confirmationService.confirm({
            message: 'Discovery is in progress.',
            header: 'Alert',
            icon: 'pi pi-info-circle',
            acceptLabel: 'Yes',
            acceptVisible: true,
            rejectVisible: false,
          });
        }),
        catchError(error => {
          console.log(error);
          alert('An error has occurred.');
          return of();
        }),
      )
      .subscribe();
  }

  ngOnDestroy(): void {
    this.preventBrowserCloseSubscription.unsubscribe();
  }

  blockDocument() {
    this.blockedDocument = true;
    setTimeout(() => {
      this.blockedDocument = false;
    }, 3000);
  }

  requestDiscover() {
    DiscoverySession.requestDiscover(this.store, this.probeService);
  }

}
