import { ElementRef } from '@angular/core';
import { Selector, createSelector } from '@ngrx/store';
import { Host, Port, Service } from '@overflow/model/discovery';
import { TargetDisplayType } from '../../../core/type';

export interface State {
  hosts: Host[] | null;
  ports: Port[] | null;
  services: Service[] | null;

  targetDisplayType: TargetDisplayType;
  refreshTargetDisplay: boolean;
  selectedTarget: {
    group: string;
    target: Host | Port | Service;
  } | null;
  targetDisplayElementRef: ElementRef;
}

export const initialState: State = {
  hosts: null,
  ports: null,
  services: null,

  targetDisplayType: TargetDisplayType.NONE,
  refreshTargetDisplay: false,
  selectedTarget: null,
  targetDisplayElementRef: null,
};

export function getSelectors<S>(selector: Selector<any, State>) {
  return {
    selectHosts: createSelector(selector, (state: State) => state.hosts),
    selectPorts: createSelector(selector, (state: State) => state.ports),
    selectServices: createSelector(selector, (state: State) => state.services),
    selectTargetDisplayType: createSelector(selector, (state: State) => state.targetDisplayType),
    selectRefreshTargetDisplay: createSelector(selector, (state: State) => state.refreshTargetDisplay),
    selectSelectedTarget: createSelector(selector, (state: State) => state.selectedTarget),
    selectTargetDisplayElementRef: createSelector(selector, (state: State) => state.targetDisplayElementRef),
  };
}
